package com.bonus.canteen.core.account.mapper;

import com.bonus.canteen.core.account.domain.AccountCard;

import java.util.List;

/**
 * 人员卡片资料Mapper接口
 * 
 * @author xsheng
 * @date 2025-04-20
 */
public interface AccCardMapper {

    public int selectAccCardCountByUserId(Long userId);

    public int selectAccCardCountByCardSerialNum(String serialNum);

    /**
     * 查询人员卡片资料
     * 
     * @param id 人员卡片资料主键
     * @return 人员卡片资料
     */
    public AccountCard selectAccCardById(Long id);

    /**
     * 查询人员卡片资料列表
     * 
     * @param accountCard 人员卡片资料
     * @return 人员卡片资料集合
     */
    public List<AccountCard> selectAccCardList(AccountCard accountCard);

    /**
     * 新增人员卡片资料
     * 
     * @param accountCard 人员卡片资料
     * @return 结果
     */
    public int insertAccCard(AccountCard accountCard);

    /**
     * 修改人员卡片资料
     * 
     * @param accountCard 人员卡片资料
     * @return 结果
     */
    public int updateAccCard(AccountCard accountCard);

    /**
     * 删除人员卡片资料
     * 
     * @param id 人员卡片资料主键
     * @return 结果
     */
    public int deleteAccCardById(Long id);

    /**
     * 批量删除人员卡片资料
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAccCardByIds(Long[] ids);
}
